pub enum Ecosystem {
Rust,
Node,
Python,
Go,
Binary,
}Expand description
A packaging ecosystem. homebrew is a distribution target, never an
ecosystem. Listed in the canonical order used for stable de-dup/expansion.
Variants
Rust
Wire value rust.
Node
Wire value node.
Python
Wire value python.
Go
Wire value go.
Binary
Wire value binary.
Implementations
Sourceimpl Ecosystem
impl Ecosystem
Sourceimpl Ecosystem
impl Ecosystem
Sourcepub fn default_registry(self) -> Registry
pub fn default_registry(self) -> Registry
The default registry for this ecosystem when targets is expanded
(SCHEMA.md 1 default-expansion table).
Sourcepub fn default_adapter(self, layout: ReleaseLayout) -> Adapter
pub fn default_adapter(self, layout: ReleaseLayout) -> Adapter
The default adapter for this ecosystem/layout when targets is expanded
(SCHEMA.md 1). Node’s default is layout-sensitive: single →
release-please, monorepo → changesets.